@@ -20,33 +20,40 @@ knitr::opts_chunk$set(
 #  TAI(PhyloExpressionSetExample)
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # visualize the TAI profile of correctly assigned Phylostrata
-#  PlotPattern(PhyloExpressionSetExample, type = "l", lwd = 6, p.value = FALSE)
+#  # Visualize the TAI profile of correctly assigned Phylostrata
+#  PlotPattern( ExpressionSet = PhyloExpressionSetExample,
+#               type          = "l",
+#               lwd           = 6,
+#               p.value       = FALSE )
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
 #  # randomly permute the Phylostratum assignment of all genes
-#  randomPhyloExpressionSetExample <- data.frame( sample(PhyloExpressionSetExample[ , 1]),
-#                                                PhyloExpressionSetExample[, 2:9] )
+#  randomPhyloExpressionSetExample <- data.frame( sample(PhyloExpressionSetExample[ , "Phylostratum"]),
+#                                                 PhyloExpressionSetExample[, 2:9] )
 #  
 #  # TAI profile based on randomly assigned Phylostrata
 #  TAI(randomPhyloExpressionSetExample)
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # visualize the TAI profile based on randomly assigned Phylostrata
-#  PlotPattern(randomPhyloExpressionSetExample, type = "l", lwd = 6, p.value = FALSE)
+#  # Visualize the TAI profile based on randomly assigned Phylostrata
+#  PlotPattern( ExpressionSet =  randomPhyloExpressionSetExample,
+#               type          = "l",
+#               lwd           = 6,
+#               p.value       = FALSE )
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # variance of the TAI profile based on correctly assigned Phylostrata
+#  # Variance of the TAI profile based on correctly assigned Phylostrata
 #  var(TAI(PhyloExpressionSetExample))
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # variance of the TAI profile based on randomly assigned Phylostrata
+#  # Variance of the TAI profile based on randomly assigned Phylostrata
 #  var(TAI(randomPhyloExpressionSetExample))
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # compute 1000 TAI profiles based on randomly assigned Phylostrata
-#  randomTAIs <- bootMatrix(PhyloExpressionSetExample, permutations = 1000)
+#  # Compute 1000 TAI profiles based on randomly assigned Phylostrata
+#  randomTAIs <- bootMatrix( ExpressionSet = PhyloExpressionSetExample,
+#                            permutations  = 1000 )
 #  
 #  head(randomTAIs)
 #  
@@ -63,8 +70,10 @@ knitr::opts_chunk$set(
 #  var_real <- var(TAI(PhyloExpressionSetExample))
 #  
 #  # visualize the distribution of variances
-#  hist(c(variance_vector,var_real), breaks = 100,
-#       xlab = "variance", main = "Histogram of variance_vector")
+#  hist( x      = c(variance_vector,var_real),
+#        breaks = 100,
+#        xlab   = "variance",
+#        main   = "Histogram of variance_vector" )
 #  
 #  # and plot a red line at the position where we can find the
 #  # real variance
@@ -78,19 +87,22 @@ knitr::opts_chunk$set(
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  # estimate the parameters: shape and rate using 'moment matching estimation'
-#  gamma_MME <- fitdistrplus::fitdist(variance_vector,distr = "gamma",method = "mme")
+#  gamma_MME <- fitdistrplus::fitdist(variance_vector,distr = "gamma", method = "mme")
 #  # estimate shape:
 #  shape <- gamma_MME$estimate[1]
 #  # estimate the rate:
 #  rate <- gamma_MME$estimate[2]
 #  
 #  # define an expression written as function as input for the curve() function
-#  gamma_distr <- function(x){ return(dgamma(x = x,shape = shape,rate = rate)) }
+#  gamma_distr <- function(x){ return(dgamma(x = x, shape = shape, rate = rate)) }
 #  
 #  # plot the density function and the histogram of variance_vector
-#  curve(gamma_distr,
-#        xlim = c(min(variance_vector),max(c(variance_vector,var_real))),
-#        col = "steelblue",lwd = 5,xlab = "Variances", ylab="Frequency")
+#  curve( expr = gamma_distr,
+#         xlim = c(min(variance_vector),max(c(variance_vector,var_real))),
+#         col  = "steelblue",
+#         lwd  = 5,
+#         xlab = "Variances",
+#         ylab = "Frequency" )
 #  
 #  # plot the histogram of variance_vector
 #  histogram <- hist(variance_vector,prob = TRUE,add = TRUE, breaks = 100)
@@ -104,14 +116,16 @@ knitr::opts_chunk$set(
 #  pgamma(var_real, shape = shape,rate = rate, lower.tail = FALSE)
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # perform the FlatLineTest
-#  FlatLineTest(PhyloExpressionSetExample, permutations = 1000)
+#  # Perform the FlatLineTest
+#  FlatLineTest( ExpressionSet = PhyloExpressionSetExample,
+#                permutations  = 1000 )
 
 ## ----, fig.width= 7, fig.height= 3,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
 #  # perform the FlatLineTest and investigate the goodness of the test statistic
-#  FlatLineTest(PhyloExpressionSetExample, permutations = 1000,
-#               plotHistogram = TRUE)
+#  FlatLineTest( ExpressionSet = PhyloExpressionSetExample,
+#                permutations  = 1000,
+#                plotHistogram = TRUE )
 #  
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -129,24 +143,27 @@ knitr::opts_chunk$set(
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  # visualize the TAI profile of correctly assigned Phylostrata
-#  PlotPattern(PhyloExpressionSetExample, type = "l", lwd = 6,
-#              p.value = FALSE)
+#  PlotPattern( ExpressionSet = PhyloExpressionSetExample,
+#               type          = "l",
+#               lwd           = 6,
+#               p.value       = FALSE )
 #  
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
-#  # perform the Reductive Hourglass Test
-#  ReductiveHourglassTest(PhyloExpressionSetExample,
-#                         modules = list(early = 1:2, mid = 3:5, late = 6:7),
-#                         lillie.test = TRUE)
+#  # Perform the Reductive Hourglass Test
+#  ReductiveHourglassTest( ExpressionSet = PhyloExpressionSetExample,
+#                          modules       = list(early = 1:2, mid = 3:5, late = 6:7),
+#                          lillie.test   = TRUE )
 #  
 
 ## ----, fig.width= 7, fig.height= 6,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
 #  # perform the Reductive Hourglass Test and plot the test statistic
-#  ReductiveHourglassTest(PhyloExpressionSetExample,
-#                         modules = list(early = 1:2, mid = 3:5, late = 6:7),
-#                         plotHistogram = TRUE, lillie.test = TRUE)
+#  ReductiveHourglassTest( ExpressionSet = PhyloExpressionSetExample,
+#                          modules       = list(early = 1:2, mid = 3:5, late = 6:7),
+#                          plotHistogram = TRUE,
+#                          lillie.test   = TRUE )
 #  
 
 ## ----,eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -163,25 +180,28 @@ knitr::opts_chunk$set(
 #  TAI(PhyloExpressionSetExample)
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-#  # visualize the TAI profile of correctly assigned Phylostrata
-#  PlotPattern(PhyloExpressionSetExample, type = "l", lwd = 6,
-#              p.value = FALSE)
+#  # Visualize the TAI profile of correctly assigned Phylostrata
+#  PlotPattern( ExpressionSet = PhyloExpressionSetExample,
+#               type          = "l",
+#               lwd           = 6,
+#               p.value       = FALSE )
 #  
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
-#  # perform the Reductive Early Conservation Test
-#  EarlyConservationTest(PhyloExpressionSetExample,
-#                         modules = list(early = 1:2, mid = 3:5, late = 6:7),
-#                         lillie.test = TRUE)
+#  # Perform the Reductive Early Conservation Test
+#  EarlyConservationTest( ExpressionSet = PhyloExpressionSetExample,
+#                         modules       = list(early = 1:2, mid = 3:5, late = 6:7),
+#                         lillie.test   = TRUE )
 #  
 
 ## ----, fig.width= 7, fig.height= 6,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
 #  # perform the Reductive Early Conservation Test and plot the test statistic
-#  EarlyConservationTest(PhyloExpressionSetExample,
-#                         modules = list(early = 1:2, mid = 3:5, late = 6:7),
-#                         plotHistogram = TRUE, lillie.test = TRUE)
+#  EarlyConservationTest( ExpressionSet = PhyloExpressionSetExample,
+#                         modules       = list(early = 1:2, mid = 3:5, late = 6:7),
+#                         plotHistogram = TRUE,
+#                         lillie.test   = TRUE )
 #  
 
 ## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
@@ -198,12 +218,12 @@ PES.sqrt <- tf(PhyloExpressionSetExample, sqrt)
 head(PES.sqrt)
 
 
-## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-
-PES.log2 <- tf(PhyloExpressionSetExample, log2)
-
-head(PES.log2)
-
+## ----, fig.width= 7, fig.height= 5, eval=FALSE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+#  
+#  PES.log2 <- tf(PhyloExpressionSetExample, log2)
+#  
+#  head(PES.log2)
+#  
 
 ## ----, fig.width= 7, fig.height= 5,eval=FALSE-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 #  
@@ -223,46 +243,59 @@ head(PES.log2)
 
 ## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 
-data(DivergenceExpressionSetExample)
+data(PhyloExpressionSetExample)
 
 # plotting the TAI using log2 transformed expression levels
 # and performing the Flat Line Test to obtain the p-value
-PlotPattern(tf(PhyloExpressionSetExample, log2),
-            type = "l", lwd = 5,  TestStatistic = "FlatLineTest",
-            xlab = "Ontogeny", ylab = "TAI")
+PlotPattern( ExpressionSet = tf(PhyloExpressionSetExample, log2),
+             type          = "l", 
+             lwd           = 5,  
+             TestStatistic = "FlatLineTest",
+             xlab          = "Ontogeny", 
+             ylab          = "TAI" )
 
 
 
 ## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 
+data(PhyloExpressionSetExample)
+
+# plotting the TAI using sqrt transformed expression levels
+# and performing the Flat Line Test to obtain the p-value
+PlotPattern( ExpressionSet = tf(PhyloExpressionSetExample, sqrt),
+             TestStatistic = "FlatLineTest",
+             type          = "l", 
+             lwd           = 5,
+             xlab          = "Ontogeny", 
+             ylab          = "TAI" )
+
+
+
+## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 data(DivergenceExpressionSetExample)
 
-# plotting the TAI using sqrt transformed expression levels
+# plotting the TDI using log2 transformed expression levels
 # and performing the Flat Line Test to obtain the p-value
-PlotPattern(tf(PhyloExpressionSetExample, sqrt),
-            type = "l", lwd = 5, TestStatistic = "FlatLineTest",
-            xlab = "Ontogeny", ylab = "TAI")
+PlotPattern( ExpressionSet = tf(DivergenceExpressionSetExample, log2),
+             TestStatistic = "FlatLineTest",
+             type          = "l", 
+             lwd           = 5,
+             xlab          = "Ontogeny", 
+             ylab          = "TDI" )
 
 
 
 ## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+data(DivergenceExpressionSetExample)
 
-# plotting the TAI using log2 transformed expression levels
+# plotting the TDI using sqrt transformed expression levels
 # and performing the Flat Line Test to obtain the p-value
-PlotPattern(tf(DivergenceExpressionSetExample, log2),
-            type = "l", lwd = 5, 
-            TestStatistic = "FlatLineTest", 
-            xlab = "Ontogeny", ylab = "TDI")
-
-
-
-## ----, fig.width= 7, fig.height= 5------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-
-# plotting the TAI using sqrt transformed expression levels
-# and performing the Flat Line Test to obtain the p-value
-PlotPattern(tf(DivergenceExpressionSetExample, sqrt),
-            type = "l", lwd = 5, TestStatistic = "FlatLineTest",
-            xlab = "Ontogeny", ylab = "TDI")
+PlotPattern( ExpressionSet = tf(DivergenceExpressionSetExample, sqrt),
+             TestStatistic = "FlatLineTest",
+             type          = "l", 
+             lwd           = 5,
+             xlab          = "Ontogeny", 
+             ylab          = "TDI" )
 
 
 
